@@ -7,11 +7,14 @@ import os
 from flask_login import LoginManager,login_user,UserMixin,login_required,logout_user,current_user
 from settings import SECRET_KEY,MONGO_URI, EMAIL_USER, MONGO_PASSWORD, MONGO_USERNAME
 from utils import send_email, get_videos
+from werkzeug.middleware.proxy_fix import ProxyFix
 
 
 
 app = Flask(__name__)
 app.secret_key = SECRET_KEY  # Secure your secret key with an environment variable 
+# 🔐 Let Flask correctly detect HTTPS and domain from proxy headers
+app.wsgi_app = ProxyFix(app.wsgi_app, x_proto=1, x_host=1)
 ### app.secret_key = SECRET_KEY isn’t an import at all—it’s just an assignment
 login_manager = LoginManager()
 
@@ -128,14 +131,22 @@ def contact_form():
         return redirect(url_for('contact_form'))
     return render_template('contact-form.html')
 
+# Update the /videos route to support both login types if does not work use this old one 
+# @app.route('/videos')
+# # @login_required
+# def private_videos():
+#     if not current_user.is_authenticated:
+#         return redirect(url_for('login'))
+#     videos = get_videos()
+#     return render_template('private-videos.html', videos=videos)
 
 @app.route('/videos')
-# @login_required
 def private_videos():
-    if not current_user.is_authenticated:
+    if not current_user.is_authenticated and 'user' not in session:
         return redirect(url_for('login'))
     videos = get_videos()
     return render_template('private-videos.html', videos=videos)
+
 @app.route("/logout")
 @login_required
 def logout():
@@ -278,14 +289,16 @@ oauth.register(
 def login_cognito():
     session.pop('user', None)
     redirect_uri = url_for('authorize', _external=True)
+    print("🧭 Redirect URI being used:", redirect_uri)  # <--- add this
     return oauth.oidc.authorize_redirect(
         redirect_uri,
-        prompt='login'  # 🔄 Forces re-authentication from Cognito
+        prompt='login'
     )
 
 
 
 
+
 # The OAuth module collects the access token and retrieves user data from the Amazon Cognito userInfo endpoint. Configure an authorize route to handle the access token and user data after authentication.
 @app.route('/authorize')
 def authorize():
